@@ -13,14 +13,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_config import cfg
+from oslo_config import fixture as conf_fixture
 from oslo_utils.fixture import uuidsentinel
 
 from blazar import context
 from blazar import tests
 
+CONF = cfg.CONF
+
 
 class TestBlazarContext(tests.TestCase):
 
+    def setUp(self):
+        super(TestBlazarContext, self).setUp()
+
+        self.cfg = self.useFixture(conf_fixture.Config(CONF))
+        self.cfg.config(os_admin_username='fake-admin')
+        self.cfg.config(os_admin_user_domain_name='fake-admin-domain')
+        self.cfg.config(os_admin_project_name='fake-admin-project')
+        self.cfg.config(os_admin_project_domain_name='fake-admin-domain')
+
     def test_to_dict(self):
         ctx = context.BlazarContext(
             user_id=111, project_id=222,
@@ -33,8 +46,6 @@ class TestBlazarContext(tests.TestCase):
             'is_admin_project': True,
             'project': 222,
             'project_domain': None,
-            'project_id': 222,
-            'project_name': None,
             'read_only': False,
             'request_id': 'req-679033b7-1755-4929-bf85-eb3bfaef7e0b',
             'resource_uuid': None,
@@ -45,15 +56,9 @@ class TestBlazarContext(tests.TestCase):
             'tenant': 222,
             'user': 111,
             'user_domain': None,
-            'user_id': 111,
-            'user_identity': u'111 222 - - -',
-            'user_name': None}
+            'user_identity': '111 222 - - -'}
         self.assertEqual(expected, ctx.to_dict())
 
-    def test_elevated_empty(self):
-        ctx = context.BlazarContext.elevated()
-        self.assertTrue(ctx.is_admin)
-
     def test_service_catalog_default(self):
         ctxt = context.BlazarContext(user_id=uuidsentinel.user_id,
                                      project_id=uuidsentinel.project_id)
@@ -69,14 +74,30 @@ class TestBlazarContext(tests.TestCase):
                                      service_catalog=None)
         self.assertEqual([], ctxt.service_catalog)
 
-    def test_blazar_context_elevated(self):
-        user_context = context.BlazarContext(
-            user_id=uuidsentinel.user_id,
-            project_id=uuidsentinel.project_id, is_admin=False)
-        self.assertFalse(user_context.is_admin)
+    def test_admin(self):
+        ctx = context.admin()
+        self.assertEqual(ctx.user_name, 'fake-admin')
+        self.assertEqual(ctx.user_domain_name, 'fake-admin-domain')
+        self.assertEqual(ctx.project_name, 'fake-admin-project')
+        self.assertEqual(ctx.project_domain_name, 'fake-admin-domain')
+        self.assertEqual(ctx.is_admin, True)
 
-        admin_context = user_context.elevated()
-        self.assertFalse(user_context.is_admin)
-        self.assertTrue(admin_context.is_admin)
-        self.assertNotIn('admin', user_context.roles)
-        self.assertIn('admin', admin_context.roles)
+    def test_admin_nested(self):
+        """Test that admin properties take priority over current context."""
+        request_id = 'req-679033b7-1755-4929-bf85-eb3bfaef7e0b'
+        service_catalog = ['foo']
+        ctx = context.BlazarContext(
+            user_name='fake-user', user_domain_name='fake-user-domain',
+            project_name='fake-project',
+            project_domain_name='fake-user-domain',
+            service_catalog=service_catalog, request_id=request_id)
+        with ctx:
+            admin_ctx = context.admin()
+            self.assertEqual(admin_ctx.user_name, 'fake-admin')
+            self.assertEqual(admin_ctx.user_domain_name, 'fake-admin-domain')
+            self.assertEqual(admin_ctx.project_name, 'fake-admin-project')
+            self.assertEqual(admin_ctx.project_domain_name,
+                             'fake-admin-domain')
+            self.assertEqual(admin_ctx.is_admin, True)
+            self.assertEqual(admin_ctx.request_id, request_id)
+            self.assertEqual(admin_ctx.service_catalog, service_catalog)
