@@ -28,7 +28,17 @@ from blazar.utils.openstack import base
 opts = [
     cfg.StrOpt('identity_service',
                default='identity',
-               help='Identity service to use.')
+               help='Identity service to use.'),
+    cfg.StrOpt('os_region_name',
+               default=None,
+               help="""
+Region name of this node. This is used when picking the URL in the service
+catalog.
+
+Possible values:
+
+* Any string representing region name
+""")
 ]
 
 keystone_opts = [
@@ -91,15 +101,20 @@ class BlazarKeystoneClient(object):
         kwargs.setdefault('version', cfg.CONF.keystone_client_version)
         if ctx is not None:
             kwargs.setdefault('username', ctx.user_name)
-            kwargs.setdefault('tenant_name', ctx.project_name)
+            kwargs.setdefault('user_domain_name', ctx.user_domain_name)
+            kwargs.setdefault('project_name', ctx.project_name)
+            kwargs.setdefault('project_domain_name', ctx.project_domain_name)
+            kwargs.setdefault('global_request_id', ctx.global_request_id)
             if not kwargs.get('auth_url'):
                 kwargs['auth_url'] = base.url_for(
-                    ctx.service_catalog, CONF.identity_service)
+                    ctx.service_catalog, CONF.identity_service,
+                    os_region_name=CONF.os_region_name)
             if not kwargs.get('trust_id'):
                 try:
                     kwargs.setdefault('endpoint', base.url_for(
                         ctx.service_catalog, CONF.identity_service,
-                        endpoint_interface='admin'))
+                        endpoint_interface='admin',
+                        os_region_name=CONF.os_region_name))
                 except AttributeError:
                     raise manager_exceptions.NoManagementUrl()
             if not kwargs.get('password'):
@@ -108,8 +123,8 @@ class BlazarKeystoneClient(object):
         # NOTE(dbelova): we need this checking to support current
         # keystoneclient: token can only be scoped now to either
         # a trust or project, not both.
-        if kwargs.get('trust_id') and kwargs.get('tenant_name'):
-            kwargs.pop('tenant_name')
+        if kwargs.get('trust_id') and kwargs.get('project_name'):
+            kwargs.pop('project_name')
 
         try:
             # NOTE(n.s.): we shall remove this try: except: clause when
